@@ -5,9 +5,9 @@ use clap::ArgMatches;
 pub(crate) mod login;
 pub(crate) mod news;
 pub(crate) mod query;
-pub(crate) mod comments;
+pub(crate) mod thread;
 pub(crate) mod tree;
-pub mod hnews;
+pub mod hacker_news;
 
 /// A trait defining the interface to add a subcommand to the command line
 /// application. 
