@@ -33,13 +33,16 @@ mod tests {
     use std::error::Error;
     use super::HNConfig;
 
+    // This test is marked as ignored, as the feature it supports is not
+    // really implemented
+    #[ignore]
     #[test]
     fn test_read_config_file() -> Result<(), Box<dyn Error>> {
         let home = std::env::var("HOME")
             .expect("Failed to read `$HOME` environment variable");
         println!("$HOME = {:?}", home);
         let mut path = PathBuf::from(home);
-        path.push(".hnews.json");
+        path.push(".hn.json");
         println!("path = {:?}", path);
 
         let config = HNConfig::from_file(&path)?;
